@@ -2,6 +2,8 @@ from bio_embeddings.extract.annotations.Disorder import Disorder
 from bio_embeddings.extract.annotations.Location import Location
 from bio_embeddings.extract.annotations.Membrane import Membrane
 from bio_embeddings.extract.annotations.SecondaryStructure import SecondaryStructure
+from bio_embeddings.extract.annotations.Conservation import Conservation
+from bio_embeddings.extract.annotations.BindingResidues import BindingResidues
 
-__all__ = ["Disorder", "Location", "Membrane", "SecondaryStructure"]
+__all__ = ["Disorder", "Location", "Membrane", "SecondaryStructure", "Conservation", "BindingResidues"]
 
